==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QQuickFramebufferObject_shell.h <==
#ifndef QQUICKFRAMEBUFFEROBJECT_SHELL_H
#define QQUICKFRAMEBUFFEROBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickframebufferobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qtransform.h>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include <QtJambi/RegistryAPI>


class QQuickFramebufferObject_shell : public QQuickFramebufferObject, public QtJambiShellInterface
{
public:
    QQuickFramebufferObject_shell(QQuickItem* parent0 = nullptr);
    ~QQuickFramebufferObject_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickFramebufferObject_mshell;
    friend class QQuickFramebufferObject_oshell;
};


class QQuickFramebufferObject_mshell : public QQuickFramebufferObject_shell
{
public:
    using QQuickFramebufferObject_shell::QQuickFramebufferObject_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickFramebufferObject_oshell : public QQuickFramebufferObject_mshell
{
public:
    using QQuickFramebufferObject_mshell::QQuickFramebufferObject_mshell;
    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    QQuickFramebufferObject::Renderer* createRenderer() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChange(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickFramebufferObject_access : public QQuickFramebufferObject
{
    jobject __qt_createRenderer_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_geometryChange_cref_QRectF_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newGeometry0, QtJambiNativeID oldGeometry1);
    jboolean __qt_isTextureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QQUICKFRAMEBUFFEROBJECT_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiQuick/QQuickFramebufferObject_shell.h <==
#ifndef QQUICKFRAMEBUFFEROBJECT_SHELL_H
#define QQUICKFRAMEBUFFEROBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickframebufferobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qtransform.h>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include <QtJambi/RegistryAPI>


class QQuickFramebufferObject_shell : public QQuickFramebufferObject, public QtJambiShellInterface
{
public:
    QQuickFramebufferObject_shell(QQuickItem* parent0 = nullptr);
    ~QQuickFramebufferObject_shell() override;

    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    QQuickFramebufferObject::Renderer* createRenderer() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChange(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickFramebufferObject_access : public QQuickFramebufferObject
{
    jobject __qt_createRenderer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_geometryChange_cref_QRectF_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newGeometry0, QtJambiNativeID oldGeometry1);
    jboolean __qt_isTextureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QQUICKFRAMEBUFFEROBJECT_SHELL_H
